@@ -4,7 +4,7 @@ use self::time::Timespec;
 use std::error::Error;
 use postgres_protocol::types;
 
-use types::{Type, FromSql, ToSql, IsNull, SessionInfo};
+use types::{Type, FromSql, ToSql, IsNull};
 
 const USEC_PER_SEC: i64 = 1_000_000;
 const NSEC_PER_USEC: i64 = 1_000;
@@ -14,10 +14,9 @@ const TIME_SEC_CONVERSION: i64 = 946684800;
 
 impl FromSql for Timespec {
     fn from_sql(_: &Type,
-                raw: &[u8],
-                _: &SessionInfo)
+                raw: &[u8])
                 -> Result<Timespec, Box<Error + Sync + Send>> {
-        let t = try!(types::timestamp_from_sql(raw));
+        let t = types::timestamp_from_sql(raw)?;
         let mut sec = t / USEC_PER_SEC + TIME_SEC_CONVERSION;
         let mut usec = t % USEC_PER_SEC;
 
@@ -35,8 +34,7 @@ impl FromSql for Timespec {
 impl ToSql for Timespec {
     fn to_sql(&self,
               _: &Type,
-              w: &mut Vec<u8>,
-              _: &SessionInfo)
+              w: &mut Vec<u8>)
               -> Result<IsNull, Box<Error + Sync + Send>> {
         let t = (self.sec - TIME_SEC_CONVERSION) * USEC_PER_SEC + self.nsec as i64 / NSEC_PER_USEC;
         types::timestamp_to_sql(t, w);
